Quick start
===========

The following modules are good entry-points to understand how to use GluonTS:

* ``gluonts.example.run_simple_feedforward``: how to train and evaluate a model.
* ``gluonts.example.benchmark``: how to evaluate and compare several model.
* ``gluonts.model.seasonal_naive``: how to implement simple models using just NumPy and Pandas.
* ``gluonts.model.simple_feedforward.estimator``: how to define a Gluon model.
